Documentation
¶
Overview ¶
Package artifacts handles OCI image layer extraction for macOS VM jobs.
When a macOS VM job specifies `container: { image: ... }` in its workflow, ephemerd pulls the OCI image via containerd and extracts all layers into a flat directory on the host filesystem. This is NOT running a container -- just unpacking the filesystem layers into a regular directory that is shared with the macOS VM via virtio-fs.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ArtifactsDir ¶
ArtifactsDir returns the artifacts directory for a given job under the data directory.
func Cleanup ¶
Cleanup removes the artifacts directory for a job. It is safe to call even if the directory does not exist.
func ListContents ¶
ListContents returns a list of file paths in the artifacts directory (for debugging).
Types ¶
type Extractor ¶
type Extractor struct {
// contains filtered or unexported fields
}
Extractor pulls OCI images and extracts their layers into host directories.
func NewExtractor ¶
NewExtractor creates an artifact extractor using the given containerd client.